@@ -1526,7 +1526,7 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
         l = self._lambd
         return "({},{},{})-Balanced Incomplete Block Design".format(v,k,l)
 
-    def arc(self, s=2, solver=None, verbose=0):
+    def arc(self, s=2, solver=None, verbose=0, *, integrality_tolerance=1e-3):
         r"""
         Return the ``s``-arc with maximum cardinality.
 
@@ -1548,17 +1548,21 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
         - ``s`` - (default to ``2``) the maximum number of points from the arc
           in each block
 
-        - ``solver`` -- (default: ``None``) Specify a Linear Program (LP)
-          solver to be used. If set to ``None``, the default one is used. For
-          more information on LP solvers and which default solver is used, see
-          the method
-          :meth:`solve <sage.numerical.mip.MixedIntegerLinearProgram.solve>`
-          of the class
-          :class:`MixedIntegerLinearProgram <sage.numerical.mip.MixedIntegerLinearProgram>`.
+        - ``solver`` -- (default: ``None``) Specify a Mixed Integer Linear
+          Programming (MILP) solver to be used. If set to ``None``, the default
+          one is used. For more information on MILP solvers and which default
+          solver is used, see the method :meth:`solve
+          <sage.numerical.mip.MixedIntegerLinearProgram.solve>` of the class
+          :class:`MixedIntegerLinearProgram
+          <sage.numerical.mip.MixedIntegerLinearProgram>`.
 
         - ``verbose`` -- integer (default: ``0``). Sets the level of
           verbosity. Set to 0 by default, which means quiet.
 
+        - ``integrality_tolerance`` -- parameter for use with MILP solvers over
+          an inexact base ring; see
+          :meth:`MixedIntegerLinearProgram.get_values`.
+
         EXAMPLES::
 
             sage: B = designs.balanced_incomplete_block_design(21, 5)
@@ -1627,7 +1631,7 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
         elif s >= max(self.block_sizes()):
             return self._points[:]
 
-        # linear program
+        # integer linear program
         from sage.numerical.mip import MixedIntegerLinearProgram
 
         p = MixedIntegerLinearProgram(solver=solver)
@@ -1636,6 +1640,8 @@ class BalancedIncompleteBlockDesign(PairwiseBalancedDesign):
         for i in self._blocks:
             p.add_constraint(p.sum(b[k] for k in i) <= s)
         p.solve(log=verbose)
-        return [self._points[i] for (i,j) in p.get_values(b).items() if j == 1]
+
+        values = p.get_values(b, convert=bool, tolerance=integrality_tolerance)
+        return [self._points[i] for (i,j) in values.items() if j]
 
 BIBD = BalancedIncompleteBlockDesign
