@@ -43,10 +43,9 @@ import time
 import resource
 import pdb
 import warnings
-import sage.misc.prandom as random
-from .lazy_string import lazy_string
-import sage.server.support
 
+from .lazy_string import lazy_string
+from sage.env import DOT_SAGE, HOSTNAME
 from sage.misc.lazy_import import lazy_import
 
 lazy_import("sage.misc.call", ["AttrCallObject", "attrcall", "call_method"],
@@ -59,8 +58,6 @@ lazy_import("sage.misc.verbose", ["verbose", "set_verbose", "set_verbose_files",
 lazy_import("sage.misc.repr", ["coeff_repr", "repr_lincomb"],
             deprecation=29892)
 
-from sage.env import DOT_SAGE, HOSTNAME
-
 LOCAL_IDENTIFIER = '%s.%s' % (HOSTNAME, os.getpid())
 
 #################################################################
@@ -96,7 +93,7 @@ def sage_makedirs(dirname, mode=0o777):
             raise
 
 
-# We create the DOT_SAGE directory (if it doesn't exist yet; note in particular
+# We create the DOT_SAGE directory (if it does not exist yet; note in particular
 # that it may already have been created by the bin/sage script) with
 # restrictive permissions, since otherwise possibly just anybody can easily see
 # every command you type.
@@ -343,9 +340,10 @@ def cputime(t=0, subprocesses=False):
         u, s = resource.getrusage(resource.RUSAGE_SELF)[:2]
         return u + s - t
     else:
+        from sage.interfaces.quit import expect_objects
         if t == 0:
             ret = GlobalCputime(cputime())
-            for s in sage.interfaces.quit.expect_objects:
+            for s in expect_objects:
                 S = s()
                 if S and S.is_running():
                     try:
@@ -359,7 +357,7 @@ def cputime(t=0, subprocesses=False):
             if not isinstance(t, GlobalCputime):
                 t = GlobalCputime(t)
             ret = GlobalCputime(cputime() - t.local)
-            for s in sage.interfaces.quit.expect_objects:
+            for s in expect_objects:
                 S = s()
                 if S and S.is_running():
                     try:
@@ -519,6 +517,8 @@ def union(x, y=None):
     EXAMPLES::
 
         sage: answer = union([1,2,3,4], [5,6]); answer
+        doctest:...: DeprecationWarning: sage.misc.misc.union is deprecated...
+        See https://trac.sagemath.org/32096 for details.
         [1, 2, 3, 4, 5, 6]
         sage: union([1,2,3,4,5,6], [5,6]) == answer
         True
@@ -527,6 +527,8 @@ def union(x, y=None):
         sage: union((1,2,3,4,5,6), set([5,6])) == answer
         True
     """
+    from sage.misc.superseded import deprecation
+    deprecation(32096, "sage.misc.misc.union is deprecated, use 'list(set(x).union(y)' or a more suitable replacement")
     if y is None:
         return list(set(x))
     return list(set(x).union(y))
@@ -833,7 +835,7 @@ class BackslashOperator:
 #################################################################
 # is_iterator function
 #################################################################
-def is_iterator(it):
+def is_iterator(it) -> bool:
     """
     Tests if it is an iterator.
 
@@ -847,13 +849,7 @@ def is_iterator(it):
         sage: is_iterator(it)
         True
 
-        sage: class wrong():  # py2
-        ....:    def __init__(self): self.n = 5
-        ....:    def next(self):
-        ....:        self.n -= 1
-        ....:        if self.n == 0: raise StopIteration
-        ....:        return self.n
-        sage: class wrong():  # py3
+        sage: class wrong():
         ....:    def __init__(self): self.n = 5
         ....:    def __next__(self):
         ....:        self.n -= 1
@@ -862,11 +858,7 @@ def is_iterator(it):
         sage: x = wrong()
         sage: is_iterator(x)
         False
-        sage: list(x)  # py2
-        Traceback (most recent call last):
-        ...
-        TypeError: iteration over non-sequence
-        sage: list(x)  # py3
+        sage: list(x)
         Traceback (most recent call last):
         ...
         TypeError: 'wrong' object is not iterable
@@ -925,8 +917,10 @@ def random_sublist(X, s):
         sage: is_sublist(sublist, S)
         True
     """
+    import sage.misc.prandom as random
     return [a for a in X if random.random() <= s]
 
+
 def is_sublist(X, Y):
     """
     Test whether ``X`` is a sublist of ``Y``.
@@ -952,6 +946,7 @@ def is_sublist(X, Y):
             X_i += 1
     return X_i == len(X)
 
+
 def some_tuples(elements, repeat, bound, max_samples=None):
     r"""
     Return an iterator over at most ``bound`` number of ``repeat``-tuples of
@@ -1029,6 +1024,7 @@ def _some_tuples_sampling(elements, repeat, max_samples, n):
         True
     """
     from sage.rings.integer import Integer
+    import sage.misc.prandom as random
     N = n if repeat is None else n**repeat
     # We sample on range(N) and create tuples manually since we don't want to create the list of all possible tuples in memory
     for a in random.sample(range(N), max_samples):
@@ -1268,19 +1264,6 @@ def pad_zeros(s, size=3):
     return "0" * (size - len(str(s))) + str(s)
 
 
-def embedded():
-    """
-    Return ``True`` if this copy of Sage is running embedded in the Sage
-    notebook.
-
-    EXAMPLES::
-
-        sage: sage.misc.misc.embedded()    # output True if in the notebook
-        False
-    """
-    return sage.server.support.EMBEDDED_MODE
-
-
 def is_in_string(line, pos):
     r"""
     Return ``True`` if the character at position ``pos`` in ``line`` occurs
